formattools.is_formattable_context_mark_for_component
=====================================================

.. autofunction:: abjad.tools.formattools.is_formattable_context_mark_for_component.is_formattable_context_mark_for_component
   :noindex:
